@@ -141,6 +141,10 @@ int load_config_file(const char* config, pbuilderconfig* pc)
 	    {
 	      pc->othermirror=strdup(delim);
 	    }
+	  else if (!strcmp(buf, "SMP"))
+	    {
+	      pc->smp=strdup(delim);
+	    }
 	  else if (!strcmp(buf, "DEBBUILDOPTS"))
 	    {
 	      pc->debbuildopts=strdup(delim);
@@ -208,6 +212,7 @@ int cpbuilder_dumpconfig(pbuilderconfig* pc)
   DUMPSTR(distribution);
   DUMPSTR(components);
   DUMPSTR(othermirror);
+  DUMPSTR(smp);
   DUMPSTR(debbuildopts);
   DUMPINT(binary_arch);
   DUMPSTR(http_proxy);
@@ -259,6 +264,7 @@ int parse_parameter(int ac, char** av,
     {"distribution", required_argument, 0, 0},
     {"components", required_argument, 0, 0},
     {"othermirror", required_argument, 0, 0},
+    {"smp", required_argument, 0, 0},
     {"debbuildopts", required_argument, 0, 0},
     {"binary-arch", no_argument, 0, 0},
     {"inputfile", required_argument, 0, 0},
@@ -280,12 +286,14 @@ int parse_parameter(int ac, char** av,
     {"debemail", required_argument, 0, 'M'},
     {"logfile", required_argument, 0, 'M'},
     {"aptconfdir", required_argument, 0, 'M'},
+    {"keyring", required_argument, 0, 'M'},
     {"timeout", required_argument, 0, 'M'},
     {"bindmounts", required_argument, 0, 'M'},
     {"debootstrapopts", required_argument, 0, 'M'},
     {"debootstrap", required_argument, 0, 'M'},
 
     /* verbatim options without argument, synced as of pbuilder 0.153 */
+    {"allow-untrusted", no_argument, 0, 'm'},
     {"removepackages", no_argument, 0, 'm'},
     {"override-config", no_argument, 0, 'm'},
     {"pkgname-logfile", no_argument, 0, 'm'},
@@ -459,6 +467,14 @@ int parse_parameter(int ac, char** av,
 	      /* this is for qemubuilder */
 	      pc.othermirror=strdup(optarg);
 
+	      /* pass it for cowbuilder */
+	      PASS_TO_PBUILDER_WITH_PARAM
+	    }
+	  else if (!strcmp(long_options[index_point].name,"smp"))
+	    {
+	      /* this is for qemubuilder */
+	      pc.smp=strdup(optarg);
+
 	      /* pass it for cowbuilder */
 	      PASS_TO_PBUILDER_WITH_PARAM
 	    }
